@@ -1,14 +1,12 @@
-import os
 import logging
 import time
 import json
 import socket
-from flask import abort, Response
 from datetime import datetime, timedelta
 from pymongo.cursor import Cursor
 from bson.objectid import ObjectId
 from flask import abort, Response
-from websocket import create_connection
+
 
 logging.basicConfig(
     level=logging.WARNING,
@@ -149,5 +147,6 @@ def handle_time_difference(start_timestamp: int, end_timestamp: int) -> float:
         end_date = datetime.fromtimestamp(end_timestamp)
     else:
         handle_abnormal(message='时间戳格式不规范', status=400,)
+
     difference = (end_date - start_date).total_seconds()
     return difference
